package com.nto.data.repository

import android.content.Context
import android.content.Context.MODE_PRIVATE
import com.nto.data.models.LoginResult
import com.nto.data.models.UserDTO
import com.nto.data.models.cards.VisitCardWrapper
import com.nto.data.utils.Provider
import dagger.hilt.android.qualifiers.ApplicationContext
import okhttp3.Credentials
import javax.inject.Inject

class DataRepositoryImpl @Inject constructor(@ApplicationContext private val context: Context) :
    DataRepository {
    override suspend fun auth(login: String, password: String): LoginResult {
        val token = Credentials.basic(login, password)
        val result = Provider.provideRetrofit().auth(
            token
        ).execute()
        if (result.isSuccessful) saveToken(token, login)
        return LoginResult(result.isSuccessful, result.message())
    }

    override suspend fun saveToken(token: String, login: String) {
        context.getSharedPreferences("auth", MODE_PRIVATE).edit().putString("token", token).putString("login", login).apply()
    }

    override suspend fun getToken(): String {
        return context.getSharedPreferences("auth", MODE_PRIVATE).getString("token", "")!!
    }

    override suspend fun getLogin(): String {
        return context.getSharedPreferences("auth", MODE_PRIVATE).getString("login", "")!!
    }

    override suspend fun getInfo(): UserDTO {
        val result = Provider.provideRetrofit().getInfo(getToken()).execute()
        return if (result.isSuccessful) result.body()!!
        else UserDTO(isError = true, isUnauthorized = result.code() == 403)
    }

    override suspend fun getVisits(id: String?): VisitCardWrapper {
        val result = Provider.provideRetrofit().getVisits(getToken()).execute()
        return if (result.isSuccessful) {
            VisitCardWrapper(result.body()!!)
        } else {
            VisitCardWrapper(null, true)
        }
    }

}