package com.nto.domain.repository

import com.nto.data.models.LoginResult
import com.nto.data.models.UserDTO
import com.nto.data.models.cards.VisitCardWrapper
import com.nto.data.repository.DataRepositoryImpl
import java.io.IOException
import javax.inject.Inject

class DomainRepositoryImpl @Inject constructor(private val dataRepositoryImpl: DataRepositoryImpl) :
    DomainRepository {
    override suspend fun auth(email: String, password: String): LoginResult {
        return try {
            dataRepositoryImpl.auth(
                login = email, password = password
            )
        } catch (e: IOException) {
            LoginResult(false, "IO exception was thrown: ${e.message}")
        }
    }

    override suspend fun saveToken(token: String, login: String) {
        dataRepositoryImpl.saveToken(token, login)
    }

    override suspend fun getToken(): String? {
        return try {
            dataRepositoryImpl.getToken()
        } catch (e: IOException) {
            null
        }
    }

    override suspend fun getInfo(): UserDTO {
        return try {
            return dataRepositoryImpl.getInfo()
        } catch (e: IOException) {
            UserDTO(isError = true)
        }
    }

    override suspend fun getVisits(id: String): VisitCardWrapper {
        return try {
            dataRepositoryImpl.getVisits(id)
        } catch (e: IOException) {
            VisitCardWrapper(null, isUnauthorized = true)
        }
    }

}