package com.nto.presentation.composable.cards

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.nto.data.models.cards.VisitCardDTO
import com.nto.data.models.cards.VisitType
import com.nto.presentation.R
import com.nto.presentation.theme.NTOTheme
import java.time.format.DateTimeFormatter

@Composable
fun VisitCard(data: VisitCardDTO, modifier: Modifier = Modifier) {
    Row(
        modifier = modifier
            .width(365.dp)
            .height(70.dp)
            .clip(RoundedCornerShape(10.dp))
            .background(NTOTheme.colors.inputFieldBackground),
    ) {
        Row(
            modifier = Modifier
                .fillMaxSize()
                .padding(start = 15.dp, end = 15.dp),
            horizontalArrangement = Arrangement.SpaceBetween,
            verticalAlignment = Alignment.CenterVertically
        ) {
            Column(horizontalAlignment = Alignment.Start) {
                Text(
                    text = data.name,
                    style = NTOTheme.typography.displaySmall,
                    fontSize = 12.sp,
                    fontWeight = FontWeight.Bold
                )
                Spacer(modifier = Modifier.height(10.dp))
                Text(
                    text = data.id.toString(),
                    style = NTOTheme.typography.displaySmall,
                    fontSize = 12.sp,
                    fontWeight = FontWeight.Thin
                )
            }
            Column(horizontalAlignment = Alignment.End) {
                Text(
                    text = data.dateString.format(DateTimeFormatter.ISO_LOCAL_DATE_TIME),
                    style = NTOTheme.typography.displaySmall,
                    fontSize = 12.sp,
                    color = NTOTheme.colors.disabledText
                )
                Spacer(modifier = Modifier.height(10.dp))
                Text(
                    text = stringResource(if (data.visitType == VisitType.PHONE_ENTRY) R.string.label_qr_login else R.string.label_card_login),
                    style = NTOTheme.typography.displaySmall,
                    fontSize = 12.sp,
                    color = NTOTheme.colors.disabledText
                )
            }
        }
    }
}

@Preview
@Composable
private fun VisitCardPreview() {
    NTOTheme {
        VisitCard(VisitCardDTO("Кабинет 207"))
    }
}